==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/copypaste/translations/copypaste_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="42"/>
        <source>Cu&amp;t</source>
        <translation>Kni&amp;ppen</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="29"/>
        <source>Copy/Paste Plugin</source>
        <translation>Kopiëren/Plakken-plug-in</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>About Copy/Paste Plugin</source>
        <translation>Over de Kopiëren/Plakken-plug-in</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Kopiëren/Plakken-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Kopiëren/Plakken-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/copypaste/translations/copypaste_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="41"/>
        <source>Cu&amp;t</source>
        <translation>Kn&amp;ippen</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="42"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation>Kopiëren/Plakken-plug-in</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation>Over de Kopiëren/Plakken-plug-in</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Kopiëren/Plakken-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Deze plug-in stelt je in staat om geselecteerde nummers te kopiëren van de ene naar de andere afspeellijst</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
